#! Flux2D 12.0

from math import *
import os
import sys
 
lastInstance = ApplicationElectricConduction2D(domain2D=Domain2DPlane(lengthUnit=LengthUnit['MILLIMETER'],
                                                       depth='6'),
                                InfinyPotential=ValueFloating())

Material(name='FLU_COPPER', propertyJE=PropertyJeTLinearFunction(slope='0.00427', rhoConstant='1.564E-8', referenceTemperature=Temperature(temperature='0.0'), temperature=Temperature(temperature='20.0')), specificHeat=RhoCpConstant(rhoCp='3518000.0'), propertyBH=PropertyBhLinear(mur='1.0'), thermalConductivity=KtIsotropic(k='394.0'))

lastInstance = RegionLine(name='Upper',
           electricConduction2D=ElectricConduction2DLineImposedElectricPotentialConstant(value='12e-3'),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'])

lastInstance = RegionLine(name='Lower',
           electricConduction2D=ElectricConduction2DLineImposedElectricPotentialConstant(value='-12e-3'),
           color=Color['Green'],
           visibility=Visibility['VISIBLE'])

lastInstance = RegionFace(name='Conductor',
           electricConduction2D=ElectricConduction2DFaceElectricConductor(material=Material['FLU_COPPER']),
           color=Color['Magenta'],
           visibility=Visibility['VISIBLE'])

Line[27,1].region=RegionLine['UPPER']


LinePropagated[36,60].region=RegionLine['LOWER']


assignRegionToFaces(face=[Face[2],
                          Face[1],
                          Face[10],
                          Face[3]],
                    region=RegionFace['CONDUCTOR'])

lastInstance = RegionFace(name='Hole',
           electricConduction2D=ElectricConduction2DFaceInactive(),
           color=Color['Magenta'],
           visibility=Visibility['VISIBLE'])

assignRegionToFaces(face=[Face[6],
                          Face[4],
                          Face[11],
                          Face[12],
                          Face[5],
                          Face[7],
                          Face[8],
                          Face[9],
                          Face[14],
                          Face[13],
                          Face[15],
                          Face[16],
                          Face[18],
                          Face[17],
                          Face[19],
                          Face[20]],
                    region=RegionFace['HOLE'])

RegionFace['HOLE'].color=Color['White']


lastInstance = SpatialParameterFormula(name='TempC',
                        SpatialFormula='20')

lastInstance = SpatialParameterFormula(name='Cu_Resistivity',
                        SpatialFormula='1.7e-8*(1+0.00427*(TempC-20))')

lastInstance = Material(name='Cu_Temp_Dep',
         propertyJE=PropertyJeLinearSpatial(rho='CU_RESISTIVITY'))

RegionFace['CONDUCTOR'].electricConduction2D=ElectricConduction2DFaceElectricConductor(material=Material['CU_TEMP_DEP'])

saveProjectAs('../ELECTRIC/physbuilt.FLU') 
