#! Flux2D 12.0
from math import *
import os
import sys



lastInstance = ApplicationThermalTransient2D(domain2D=Domain2DPlane(lengthUnit=LengthUnit['MILLIMETER'],
                                                                                                  depth='6'),
                                                   temperatureUnit=Unit['CELSIUS_DEGREE'],
                                                   transientInitialization=TransientInitializationZeroInitialSolution()) 
 
Material(name='FLU_COPPER',
         propertyBH=PropertyBhLinear(mur='1.0'),
         propertyJE=PropertyJeTLinearFunction(slope='0.00427',
                                                                                  rhoConstant='1.564E-8',
                                                                                  referenceTemperature=Temperature(temperature='0.0',
                                                                                                                                                   unit=Unit['Kelvin']),
                                                                                  temperature=Temperature(temperature='20.0',
                                                                                                                                  unit=Unit['Kelvin'])),
         thermalConductivity=KtIsotropic(k='394.0'),
         specificHeat=RhoCpConstant(rhoCp='3518000.0'))

RegionLine(name='HOLES',
           thermalTransient2D=Thermal2DLineThermalExchanges(coefExchanges=ExchangeConstant(tExternal=ioTemperature(temperature='293.15',
                                                                                                                                                                                                                           unit=Unit['Kelvin']),
                                                                                                                                                                           value=['20',
                                                                                                                                                                                          '.8'])),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'])


RegionLine(name='LEFT',
           thermalTransient2D=Thermal2DLineThermalExchanges(coefExchanges=ExchangeConstant(tExternal=ioTemperature(temperature='293.15',
                                                                                                                                                                                                                           unit=Unit['Kelvin']),
                                                                                                                                                                           value=['1',
                                                                                                                                                                                          '.8'])),
           color=Color['Yellow'],
           visibility=Visibility['VISIBLE'])


RegionLine(name='LOWER_HEAT_SINK',
           thermalTransient2D=Thermal2DLineImposedTemperatureConstant(value='293.15',
                                                                                                                                  unit=Unit['Kelvin']),
           color=Color['Green'],
           visibility=Visibility['VISIBLE'])

RegionLine(name='RIGHT',
           thermalTransient2D=Thermal2DLineThermalExchanges(coefExchanges=ExchangeConstant(tExternal=ioTemperature(temperature='293.15',
                                                                                                                                                                                                                           unit=Unit['Kelvin']),
                                                                                                                                                                           value=['10',
                                                                                                                                                                                          '.8'])),
           color=Color['Black'],
           visibility=Visibility['VISIBLE'])


RegionLine(name='UPPER',
           thermalTransient2D=Thermal2DLineThermalExchanges(coefExchanges=ExchangeConstant(tExternal=ioTemperature(temperature='293.15',
                                                                                                                                                                                                                           unit=Unit['Kelvin']),
                                                                                                                                                                           value=['5',
                                                                                                                                                                                          '.8'])),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'])
           

           
RegionFace(name='CONDUCTOR',
           thermalTransient2D=Thermal2DFaceThermalConductor(transparency='automatic',
                                                                                                                material=Material['FLU_COPPER'],
                                                                                                                heat=VolumeHeatSourceSpatialFormula(value='80')),
           color=Color['White'],
           visibility=Visibility['VISIBLE'])


RegionFace(name='HOLE',
           thermalTransient2D=Thermal2DFaceInactive(transparency='automatic'),
           color=Color['Magenta'],
           visibility=Visibility['VISIBLE'])


Line[27,1].region=RegionLine['UPPER']


LinePropagated[36,60].region=RegionLine['LOWER_HEAT_SINK']

Line[26,25,24,39,38,37,59,58,57,4,3,2].region=RegionLine['LEFT']

Line[2,3,4,57,58,59].region=RegionLine['RIGHT']     

Line[7,8,10,14,15,16,17,18,20,22,28,29,30,31,33,32,35,34,42,40,45,44,47,46,52,48,55,54].region=RegionLine['HOLES']     
assignRegionToFaces(face=[Face[2],
                                           Face[1],
                                           Face[10],
                                           Face[3]],
                                 region=RegionFace['CONDUCTOR'])
  
assignRegionToFaces(face=[Face[6],
                                           Face[4],
                                           Face[11],
                                           Face[12],
                                           Face[5],
                                           Face[7],
                                           Face[8],
                                           Face[9],
                                           Face[14],
                                           Face[13],
                                           Face[15],
                                           Face[16],
                                           Face[18],
                                           Face[17],
                                           Face[19],
                                           Face[20]],
                                 region=RegionFace['HOLE'])

RegionFace['HOLE'].color=Color['Turquoise']
RegionLine['LEFT'].color=Color['Yellow']	 

   
result = checkPhysic()
saveProjectAs('../THERMAL/physbuilt.FLU') 
    
